@@ -185,7 +185,7 @@ class Data_Preprocessor:
 
     '''
 
-    def __init__(self, features, targets, pca={}):
+    def __init__(self, features, targets, pca={}, TRAIN=False):
         '''
         Constructs the necessary attributes for the DataPreprocessor object.
 
@@ -198,6 +198,8 @@ class Data_Preprocessor:
                 list containing only one target name in a form: ['TARGET_NAME']
             pca : dict
                 dictionary of PCA-transformers (default: empty dictionary)
+            TRAIN : bool
+                default: False for self.mode='predict'
 
         Raises
         ------
@@ -217,7 +219,7 @@ class Data_Preprocessor:
             # default
             self.is_features_invoked = False
 
-        self.mode = 'predict' if pca else 'train'
+        self.mode = 'train' if TRAIN else 'predict'
 
     def get_pca(self):
         return self.pca
